from typing import List
from sqlalchemy import Boolean, Column, ForeignKey, Integer, String, JSON, DateTime
from sqlalchemy.orm import relationship, Mapped, mapped_column, DeclarativeBase
from sqlalchemy_utils import ChoiceType
from sqlalchemy.orm import mapped_column

from datetime import datetime

from .schemas import WebsiteCheck

class Base(DeclarativeBase):
    type_annotation_map = {
        List[WebsiteCheck]: JSON,
        dict: JSON
        }

class Definition(Base):
    __tablename__ = "definitions"

    id : Mapped[int]= mapped_column(primary_key=True)
    domain : Mapped[str] = mapped_column()
    path : Mapped[str] = mapped_column()
    # checks : Mapped[List[WebsiteCheck]] = mapped_column()
    tasks : Mapped[List["Task"]] = relationship(back_populates="definition")


class Task(Base):
    __tablename__ = "tasks"
    
    id : Mapped[int] = mapped_column(primary_key=True)
    # XXX enforce "ok" | "nok" | "unknown"
    status: Mapped[str] = mapped_column(default="unknown")
    max_delta_days: Mapped[int] = mapped_column()
    response: Mapped[dict] = mapped_column(default={})
    last_check: Mapped[datetime] = mapped_column(nullable=True)
    selected_by: Mapped[str] = mapped_column(nullable=True)
    selected_at: Mapped[datetime] = mapped_column(nullable=True)
    definition_id : Mapped[str] = mapped_column(ForeignKey("definitions.id"))
    definition : Mapped["Definition"] = relationship(back_populates="tasks")