from sqlalchemy.orm import Session

from . import models, schemas
from .logging import logger


def list_tasks(db: Session, limit: int = 100):
    return db.query(models.Task).limit(limit).all()


def update_from_config(db: Session, config: schemas.Config):
    for website in config.websites:
        domain = website.domain
        for p in website.paths:
            definition = models.Definition(
                domain = str(website.domain),
                path = str(p.path),
            )
            db.add(definition)

            for check in p.checks:
                for check_key, check_value in check.items():
                    logger.debug(f"{check_key=}, {check_value=}")
                    task = models.Task(
                        definition=definition,
                        status= "unknown",
                        max_delta_days = 1, #XXX This should be defined in the config.
                    )
                    db.add(task)
    db.commit()
